# Generated by roxygen2: do not edit by hand

S3method(print,cre_deal_result)
S3method(print,cre_deal_spec)
S3method(print,cre_lease_event)
S3method(print,cre_lease_roll)
S3method(print,cre_lease_unit)
S3method(summary,cre_deal_result)
S3method(summary,cre_lease_roll)
S3method(summary,cre_lease_unit)
export(add_credit_ratios)
export(analyze_deal)
export(as_rate)
export(as_yaml)
export(asset_snapshot)
export(build_lease_table)
export(cf_compute_levered)
export(cf_make_full_table)
export(cfg_explain)
export(cfg_missing)
export(cfg_normalize)
export(cfg_validate)
export(compare_financing_scenarios)
export(compute_equity_invest)
export(compute_leveraged_metrics)
export(compute_noi_y1)
export(compute_unleveraged_metrics)
export(dcf_add_noi_columns)
export(dcf_calculate)
export(dcf_read_config)
export(dcf_spec_template)
export(dcf_write_yaml_template)
export(deal_cashflows)
export(deal_spec)
export(deal_to_config)
export(debt_built_schedule)
export(debt_terms)
export(depreciation_spec)
export(derive_exit_yield)
export(equity_multiple_safe)
export(flag_covenants)
export(forward_value_from_noi)
export(get_cfg)
export(guard_rate)
export(init_debt_fees)
export(interest_rule)
export(irr_partition)
export(irr_safe)
export(lease_effective_rent)
export(lease_event)
export(lease_roll)
export(lease_roll_snapshot)
export(lease_unit)
export(leases_tbl_structuration)
export(loss_rule)
export(npv_rate)
export(price_from_cap)
export(project_terminal_noi)
export(renewal_event)
export(run_case)
export(run_from_config)
export(select_terminal_noi)
export(simulate_shock)
export(styles_breach_counts)
export(styles_break_even_exit_yield)
export(styles_distressed_exit)
export(styles_equity_cashflows)
export(styles_exit_sensitivity)
export(styles_growth_sensitivity)
export(styles_manifest)
export(styles_pv_split)
export(styles_revalue_yield_plus_growth)
export(sweep_sensitivities)
export(tax_basis_spv)
export(tax_run_spv)
export(tax_spec_spv)
export(test_refi)
export(underwrite_loan)
export(vacancy_event)
importFrom(checkmate,assert_data_frame)
importFrom(checkmate,assert_integerish)
importFrom(checkmate,assert_number)
importFrom(checkmate,assert_numeric)
importFrom(dplyr,bind_rows)
importFrom(dplyr,lag)
importFrom(dplyr,lead)
importFrom(dplyr,mutate)
importFrom(magrittr,"%>%")
importFrom(stats,uniroot)
importFrom(tibble,tibble)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(yaml,read_yaml)
importFrom(yaml,write_yaml)
